/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.event.listeners;

import org.ow2.util.ee.event.types.AbstractEvent;
import org.ow2.util.event.api.EventPriority;
import org.ow2.util.event.api.IEvent;
import org.ow2.util.event.api.IEventListener;

/**
 * Abstract event listener.
 * @author eyindanga
 */
public abstract class AbsBeanEventListener implements IEventListener {
    /**
     * Event provider filter.
     */
    private String eventProviderFilter = null;

    /**
     * Contructor.
     * @param providerFilter provider filter
     */
    public AbsBeanEventListener(final String eventProviderFilter) {
        this.eventProviderFilter = eventProviderFilter;
    }

    /*
     * (non-Javadoc)
     * @see org.ow2.util.event.api.IEventListener#accept(org.ow2.util.event.api.IEvent)
     */
    public boolean accept(final IEvent event) {
        try {
            return ((AbstractEvent) event).getEventProviderFilter().matches(eventProviderFilter);
        } catch (Exception e) {
            return false;
        }

    }

    /*
     * (non-Javadoc)
     * @see org.ow2.util.event.api.IEventListener#getPriority()
     */
    public EventPriority getPriority() {
        return EventPriority.ASYNC_HIGH;
    }

    /*
     * (non-Javadoc)
     * @see org.ow2.util.event.api.IEventListener#handle(org.ow2.util.event.api.IEvent)
     */
    public abstract void handle(final IEvent event);

    /**
     * @return the eventProviderFilter
     */
    public String getEventProviderFilter() {
        return eventProviderFilter;
    }

    /**
     * @param eventProviderFilter the eventProviderFilter to set
     */
    public void setEventProviderFilter(final String eventProviderFilter) {
        this.eventProviderFilter = eventProviderFilter;
    }

}
