/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.event.types;

import org.ow2.util.event.api.IEvent;
import org.ow2.util.event.api.IEventListener;
/**
 * Abstract parent class for all Bean events.
 * @author eyindanga
 */
public abstract class AbstractEvent implements IEvent {

    /**
     * The next event number.
     */
    private static long nextNumber = 1;

    /**
     * The event number.
     */
    private long number;

    /**
     * The event time.
     */
    private long time;

    /**
     * The event source.
     */
    private String source;

    /**
     * Event provider filster.
     */

    private String eventProviderFilter = null;

    /**
     * The default constructor.
     * @param source The event source.
     */
    public AbstractEvent(final String source) {
        this.number = AbstractEvent.nextNumber++;
        this.time = System.currentTimeMillis();
        this.source = source;
    }

    /**
     * Get the event number.
     * @return The event number.
     */
    public long getNumber() {
        return this.number;
    }

    /**
     * Get the event time (ms).
     * @return The event time (ms).
     */
    public long getTime() {
        return this.time;
    }

    /**
     * Get the event provider id.
     * @return The event provider id.
     */
    public String getEventProviderId() {
        return this.source;
    }

    /**
     * Check whether the event listener has permission to receive this event.
     * @param eventListener The event listener to check.
     * @return True if the listener has the permission, false otherwise.
     */
    public boolean checkPermission(final IEventListener eventListener){
        return true;
    }

    /**
     * @return the eventProviderFilter
     */
    public String getEventProviderFilter() {
        return eventProviderFilter;
    }

    /**
     * @param eventProviderFilter the eventProviderFilter to set
     */
    public void setEventProviderFilter(final String eventProviderFilter) {
        this.eventProviderFilter = eventProviderFilter;
    }

}
